@@ -46,7 +46,6 @@
 #include <kmessagebox.h>
 #include <ktitlewidget.h>
 
-#include "kdepackages.h"
 #include "../kxmlgui_version.h"
 #include "systeminformation_p.h"
 #include "config-xmlgui.h"
@@ -67,7 +66,6 @@ public:
 
     void _k_slotConfigureEmail();
     void _k_slotSetFrom();
-    void _k_appChanged(int);
     void _k_updateUrl();
 
     KBugReport *q;
@@ -82,7 +80,6 @@ public:
     QGroupBox *m_bgSeverity;
     QPushButton *m_configureEmail;
 
-    QComboBox *appcombo;
     QString lastError;
     QString kde_version;
     QString appname;
@@ -103,7 +100,7 @@ public:
 KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
     : QDialog(_parent), d(new KBugReportPrivate(this))
 {
-    setWindowTitle(i18n("Submit Bug Report"));
+    setWindowTitle(i18nc("@title:window", "Submit Bug Report"));
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(this);
     buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
@@ -152,8 +149,7 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
         d->m_from->setWhatsThis(qwtstr);
 
         // Configure email button
-        d->m_configureEmail = new QPushButton(i18n("Configure Email..."),
-                                              this);
+        d->m_configureEmail = new QPushButton(i18nc("@action:button", "Configure Email..."), this);
         connect(d->m_configureEmail, SIGNAL(clicked()), this,
                 SLOT(_k_slotConfigureEmail()));
         glay->addWidget(d->m_configureEmail, 0, 2, 3, 1, Qt::AlignTop | Qt::AlignRight);
@@ -169,8 +165,9 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
         tmpLabel->setWhatsThis(qwtstr);
 
         KGuiItem::assign(buttonBox->button(QDialogButtonBox::Ok),
-                         KGuiItem(i18n("&Send"), QStringLiteral("mail-send"), i18n("Send bug report."),
-                                  i18n("Send this bug report to %1.", d->m_aboutData.bugAddress())));
+                         KGuiItem(i18nc("@action:button", "&Send"), QStringLiteral("mail-send"),
+                                  i18nc("@info:tooltip", "Send bug report."),
+                                  i18nc("@info:whatsthis", "Send this bug report to %1.", d->m_aboutData.bugAddress())));
         row++;
     } else {
         d->m_configureEmail = nullptr;
@@ -182,27 +179,10 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
     tmpLabel = new QLabel(i18n("Application: "), this);
     glay->addWidget(tmpLabel, row, 0);
     tmpLabel->setWhatsThis(qwtstr);
-    d->appcombo = new QComboBox(this);
-    d->appcombo->setWhatsThis(qwtstr);
-    QStringList packageList;
-    for (int c = 0; packages[c]; ++c) {
-        packageList << QString::fromLatin1(packages[c]);
-    }
-    d->appcombo->addItems(packageList);
-    connect(d->appcombo, SIGNAL(activated(int)), SLOT(_k_appChanged(int)));
+    QLabel *appLabel = new QLabel(this);
     d->appname = d->m_aboutData.productName();
-    glay->addWidget(d->appcombo, row, 1);
-    int index = 0;
-    for (; index < d->appcombo->count(); index++) {
-        if (d->appcombo->itemText(index) == d->appname) {
-            break;
-        }
-    }
-    if (index == d->appcombo->count()) { // not present
-        d->appcombo->addItem(d->appname);
-    }
-    d->appcombo->setCurrentIndex(index);
-
+    appLabel->setText(d->appname);
+    glay->addWidget(appLabel, row, 1);
     tmpLabel->setWhatsThis(qwtstr);
 
     // Version
@@ -232,23 +212,17 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
     tmpLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
     glay->addWidget(tmpLabel, row, 1, 1, 2);
 
-    tmpLabel = new QLabel(i18n("Compiler:"), this);
-    glay->addWidget(tmpLabel, ++row, 0);
-    tmpLabel = new QLabel(QLatin1String(XMLGUI_COMPILER_VERSION), this);
-    tmpLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
-    glay->addWidget(tmpLabel, row, 1, 1, 2);
-
     if (d->bugDestination == KBugReportPrivate::CustomEmail) {
         // Severity
-        d->m_bgSeverity = new QGroupBox(i18n("Se&verity"), this);
+        d->m_bgSeverity = new QGroupBox(i18nc("@title:group", "Se&verity"), this);
 
         struct SeverityData { QString name; QString text; };
         const std::array<SeverityData, 5> severityData = { {
-            { QStringLiteral("critical"), i18n("Critical") },
-            { QStringLiteral("grave"),    i18n("Grave") },
-            { QStringLiteral("normal"),   i18nc("normal severity", "Normal") },
-            { QStringLiteral("wishlist"), i18n("Wishlist") },
-            { QStringLiteral("i18n"),     i18n("Translation") },
+            { QStringLiteral("critical"), i18nc("bug severity", "Critical") },
+            { QStringLiteral("grave"),    i18nc("bug severity", "Grave") },
+            { QStringLiteral("normal"),   i18nc("bug severity", "Normal") },
+            { QStringLiteral("wishlist"), i18nc("bug severity", "Wishlist") },
+            { QStringLiteral("i18n"),     i18nc("bug severity", "Translation") },
         } };
 
         QHBoxLayout *severityLayout = new QHBoxLayout(d->m_bgSeverity);
@@ -314,13 +288,12 @@ KBugReport::KBugReport(const KAboutData &aboutData, QWidget *_parent)
         lay->addWidget(label);
         lay->addSpacing(10);
 
-        d->appcombo->setFocus();
 
         QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
         if (d->bugDestination == KBugReportPrivate::BugsKdeOrg) {
-            okButton->setText(i18n("&Launch Bug Report Wizard"));
+            okButton->setText(i18nc("@action:button", "&Launch Bug Report Wizard"));
         } else {
-            okButton->setText(i18n("&Submit Bug Report"));
+            okButton->setText(i18nc("@action:button", "&Submit Bug Report"));
         }
         okButton->setIcon(QIcon::fromTheme(QStringLiteral("tools-report-bug")));
     }
@@ -357,7 +330,7 @@ void KBugReportPrivate::_k_updateUrl()
     query.addQueryItem(QStringLiteral("format"), QStringLiteral("guided"));    // use the guided form
 
     // the string format is product/component, where component is optional
-    QStringList list = appcombo->currentText().split(QLatin1Char('/'));
+    QStringList list = appname.split(QLatin1Char('/'));
     query.addQueryItem(QStringLiteral("product"), list[0]);
     if (list.size() == 2) {
         query.addQueryItem(QStringLiteral("component"), list[1]);
@@ -369,35 +342,6 @@ void KBugReportPrivate::_k_updateUrl()
     // TODO: guess and fill OS(sys_os) and Platform(rep_platform) fields
 }
 
-void KBugReportPrivate::_k_appChanged(int i)
-{
-    QString appName = appcombo->itemText(i);
-    int index = appName.indexOf(QLatin1Char('/'));
-    if (index > 0) {
-        appName.truncate(index);
-    }
-    //qCDebug(DEBUG_KXMLGUI) << "appName " << appName;
-
-    QString strDisplayVersion; //Version string to show in the UI
-    if (appname == appName && !m_aboutData.version().isEmpty()) {
-        m_strVersion = m_aboutData.version();
-        strDisplayVersion = m_strVersion;
-    } else {
-        m_strVersion = QStringLiteral("unknown"); //English string to put in the bug report
-        strDisplayVersion = i18nc("unknown program name", "unknown");
-    }
-
-    if (bugDestination != KBugReportPrivate::BugsKdeOrg) {
-        m_strVersion += QLatin1Char(' ') + kde_version;
-        strDisplayVersion += QLatin1Char(' ') + kde_version;
-    }
-
-    m_version->setText(strDisplayVersion);
-    if (bugDestination == KBugReportPrivate::BugsKdeOrg) {
-        _k_updateUrl();
-    }
-}
-
 void KBugReportPrivate::_k_slotConfigureEmail()
 {
     if (m_process) {
@@ -496,7 +440,8 @@ void KBugReport::closeEvent(QCloseEvent *e)
         ((d->m_lineedit->toPlainText().length() > 0) || d->m_subject->isModified())) {
         int rc = KMessageBox::warningYesNo(this,
                                            i18n("Close and discard\nedited message?"),
-                                           i18n("Close Message"), KStandardGuiItem::discard(), KStandardGuiItem::cont());
+                                           i18nc("@title:window", "Close Message"),
+                                           KStandardGuiItem::discard(), KStandardGuiItem::cont());
         if (rc == KMessageBox::No) {
             e->ignore();
             return;
@@ -510,7 +455,7 @@ QString KBugReport::text() const
     //qCDebug(DEBUG_KXMLGUI) << d->severityButtons[d->currentSeverity()]->objectName();
     // Prepend the pseudo-headers to the contents of the mail
     QString severity = d->severityButtons[d->currentSeverity()]->objectName();
-    QString appname = d->appcombo->currentText();
+    QString appname = d->appname;
     QString os = QStringLiteral("OS: %1 (%2)\n").
                  arg(QStringLiteral(XMLGUI_COMPILING_OS),
                      QStringLiteral(XMLGUI_DISTRIBUTION_TEXT));
@@ -544,7 +489,6 @@ QString KBugReport::text() const
         return QLatin1String("Package: ") + appname +
                QLatin1String("\nVersion: ") + d->m_strVersion +
                QLatin1String("\nSeverity: ") + severity +
-               QLatin1String("\nCompiler: ") + QStringLiteral(XMLGUI_COMPILER_VERSION) +
                QLatin1Char('\n') + os +
                QLatin1Char('\n') + bodyText;
     }
@@ -568,7 +512,7 @@ bool KBugReport::sendBugReport()
     proc.start(command, args);
     //qCDebug(DEBUG_KXMLGUI) << command << args;
     if (!proc.waitForStarted()) {
-        qCritical() << "Unable to open a pipe to " << command << endl;
+        qCritical() << "Unable to open a pipe to " << command;
         return false;
     }
     proc.write(text().toUtf8());
