@@ -344,7 +344,7 @@ ToolBarItem *ToolBarListWidget::currentItem() const
 IconTextEditDialog::IconTextEditDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Change Text"));
+    setWindowTitle(i18nc("@title:window", "Change Text"));
     setModal(true);
 
     QVBoxLayout *layout = new QVBoxLayout;
@@ -360,7 +360,7 @@ IconTextEditDialog::IconTextEditDialog(QWidget *parent)
     grid->addWidget(label, 0, 0);
     grid->addWidget(m_lineEdit, 0, 1);
 
-    m_cbHidden = new QCheckBox(i18n("&Hide text when toolbar shows text alongside icons"), this);
+    m_cbHidden = new QCheckBox(i18nc("@option:check", "&Hide text when toolbar shows text alongside icons"), this);
     grid->addWidget(m_cbHidden, 1, 1);
 
     layout->addLayout(grid);
@@ -507,9 +507,8 @@ public:
 #ifndef NDEBUG
     void dump() const
     {
-        XmlDataList::const_iterator xit = m_xmlFiles.begin();
-        for (; xit != m_xmlFiles.end(); ++xit) {
-            (*xit).dump();
+        for (const auto &xmlFile : m_xmlFiles) {
+            xmlFile.dump();
         }
     }
 #endif
@@ -614,7 +613,7 @@ void KEditToolBarPrivate::init()
 
     q->setDefaultToolBar(QString());
 
-    q->setWindowTitle(i18n("Configure Toolbars"));
+    q->setWindowTitle(i18nc("@title:window", "Configure Toolbars"));
     q->setModal(false);
 
     m_layout = new QVBoxLayout;
@@ -686,7 +685,8 @@ void KEditToolBarPrivate::defaultClicked()
     m_accept = false;
 
     if (m_factory) {
-        foreach (KXMLGUIClient *client, m_factory->clients()) {
+        const auto clients = m_factory->clients();
+        for (KXMLGUIClient *client : clients) {
             const QString file = client->localXMLFile();
             if (file.isEmpty()) {
                 continue;
@@ -732,7 +732,9 @@ void KEditToolBarPrivate::defaultClicked()
     _k_enableApply(false);
 
     emit q->newToolBarConfig();
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(4, 0)
     emit q->newToolbarConfig(); // compat
+#endif
 }
 
 void KEditToolBarPrivate::_k_slotButtonClicked(QAbstractButton *button)
@@ -766,7 +768,9 @@ void KEditToolBarPrivate::okClicked()
     if (m_buttonBox->button(QDialogButtonBox::Apply)->isEnabled()) {
         m_widget->save();
         emit q->newToolBarConfig();
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(4, 0)
         emit q->newToolbarConfig(); // compat
+#endif
     }
     q->accept();
 }
@@ -776,7 +780,9 @@ void KEditToolBarPrivate::applyClicked()
     (void)m_widget->save();
     _k_enableApply(false);
     emit q->newToolBarConfig();
+#if KXMLGUI_BUILD_DEPRECATED_SINCE(4, 0)
     emit q->newToolbarConfig(); // compat
+#endif
 }
 
 void KEditToolBar::setGlobalDefaultToolBar(const char *toolbarName)
@@ -869,7 +875,8 @@ void KEditToolBarWidgetPrivate::initFromFactory(KXMLGUIFactory *factory,
 
     // add all of the client data
     bool first = true;
-    foreach (KXMLGUIClient *client, factory->clients()) {
+    const auto clients = factory->clients();
+    for (KXMLGUIClient *client : clients) {
         if (client->xmlFile().isEmpty()) {
             continue;
         }
@@ -899,7 +906,8 @@ void KEditToolBarWidgetPrivate::initFromFactory(KXMLGUIFactory *factory,
     m_widget->setMinimumSize(m_widget->sizeHint());
 
     m_widget->actionCollection()->addAssociatedWidget(m_widget);
-    foreach (QAction *action, m_widget->actionCollection()->actions()) {
+    const auto widgetActions = m_widget->actionCollection()->actions();
+    for (QAction *action : widgetActions) {
         action->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     }
 }
@@ -907,20 +915,19 @@ void KEditToolBarWidgetPrivate::initFromFactory(KXMLGUIFactory *factory,
 void KEditToolBarWidget::save()
 {
     //qDebug(240) << "KEditToolBarWidget::save";
-    XmlDataList::Iterator it = d->m_xmlFiles.begin();
-    for (; it != d->m_xmlFiles.end(); ++it) {
+    for (const auto &xmlFile : qAsConst(d->m_xmlFiles)) {
         // let's not save non-modified files
-        if (!((*it).m_isModified)) {
+        if (!xmlFile.m_isModified) {
             continue;
         }
 
         // let's also skip (non-existent) merged files
-        if ((*it).type() == XmlData::Merged) {
+        if (xmlFile.type() == XmlData::Merged) {
             continue;
         }
 
         // Add noMerge="1" to all the menus since we are saving the merged data
-        QDomNodeList menuNodes = (*it).domDocument().elementsByTagName(QStringLiteral("Menu"));
+        QDomNodeList menuNodes = xmlFile.domDocument().elementsByTagName(QStringLiteral("Menu"));
         for (int i = 0; i < menuNodes.length(); ++i) {
             QDomNode menuNode = menuNodes.item(i);
             QDomElement menuElement = menuNode.toElement();
@@ -934,7 +941,7 @@ void KEditToolBarWidget::save()
 
         //qDebug(240) << "Saving " << (*it).xmlFile();
         // if we got this far, we might as well just save it
-        KXMLGUIFactory::saveConfigFile((*it).domDocument(), (*it).xmlFile());
+        KXMLGUIFactory::saveConfigFile(xmlFile.domDocument(), xmlFile.xmlFile());
     }
 
     if (!d->m_factory) {
@@ -970,7 +977,7 @@ void KEditToolBarWidget::rebuildKXMLGUIClients()
 
     // now, rebuild the gui from the first to the last
     //qDebug(240) << "rebuilding the gui";
-    foreach (KXMLGUIClient *client, clients) {
+    for (KXMLGUIClient *client : clients) {
         //qDebug(240) << "updating client " << client << " " << client->componentName() << "  xmlFile=" << client->xmlFile();
         QString file(client->xmlFile());   // before setting ui_standards!
         if (!file.isEmpty()) {
@@ -992,7 +999,7 @@ void KEditToolBarWidget::rebuildKXMLGUIClients()
     // Now we can add the clients to the factory
     // We don't do it in the loop above because adding a part automatically
     // adds its plugins, so we must make sure the plugins were updated first.
-    foreach (KXMLGUIClient *client, clients) {
+    for (KXMLGUIClient *client : clients) {
         d->m_factory->addClient(client);
     }
 }
@@ -1052,7 +1059,7 @@ void KEditToolBarWidgetPrivate::setupLayout()
     activeListSearchLine->setPlaceholderText(i18n("Filter"));
 
     // "change icon" button
-    m_changeIcon = new QPushButton(i18n("Change &Icon..."), m_widget);
+    m_changeIcon = new QPushButton(i18nc("@action:button", "Change &Icon..."), m_widget);
     m_changeIcon->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-icons")));
     m_changeIcon->setEnabled(m_activeList->currentItem());
 
@@ -1060,7 +1067,7 @@ void KEditToolBarWidgetPrivate::setupLayout()
                      m_widget, SLOT(slotChangeIcon()));
 
     // "change icon text" button
-    m_changeIconText = new QPushButton(i18n("Change Te&xt..."), m_widget);
+    m_changeIconText = new QPushButton(i18nc("@action:button", "Change Te&xt..."), m_widget);
     m_changeIconText->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
     m_changeIconText->setEnabled(m_activeList->currentItem() != nullptr);
 
@@ -1153,21 +1160,19 @@ void KEditToolBarWidgetPrivate::loadToolBarCombo(const QString &defaultToolBar)
     int defaultToolBarId = -1;
     int count = 0;
     // load in all of the toolbar names into this combo box
-    XmlDataList::const_iterator xit = m_xmlFiles.constBegin();
-    for (; xit != m_xmlFiles.constEnd(); ++xit) {
+    for (const auto &xmlFile : qAsConst(m_xmlFiles)) {
         // skip the merged one in favor of the local one,
         // so that we can change icons
         // This also makes the app-defined named for "mainToolBar" appear rather than the ui_standards-defined name.
-        if ((*xit).type() == XmlData::Merged) {
+        if (xmlFile.type() == XmlData::Merged) {
             continue;
         }
 
         // each xml file may have any number of toolbars
-        ToolBarList::const_iterator it = (*xit).barList().begin();
-        for (; it != (*xit).barList().constEnd(); ++it) {
-            const QString text = (*xit).toolBarText(*it);
+        for (const auto &bar : qAsConst(xmlFile.barList())) {
+            const QString text = xmlFile.toolBarText(bar);
             m_toolbarCombo->addItem(text);
-            const QString name = (*it).attribute(attrName);
+            const QString name = bar.attribute(attrName);
             if (defaultToolBarId == -1 && name == defaultToolBar) {
                 defaultToolBarId = count;
             }
@@ -1260,7 +1265,8 @@ void KEditToolBarWidgetPrivate::loadActions(const QDomElement &elem)
         // iterate through this client's actions
         // This used to iterate through _all_ actions, but we don't support
         // putting any action into any client...
-        foreach (QAction *action, actionCollection->actions()) {
+        const auto actions = actionCollection->actions();
+        for (QAction *action : actions) {
             // do we have a match?
             if (it.attribute(attrName) == action->objectName()) {
                 // we have a match!
@@ -1276,7 +1282,8 @@ void KEditToolBarWidgetPrivate::loadActions(const QDomElement &elem)
     }
 
     // go through the rest of the collection
-    foreach (QAction *action, actionCollection->actions()) {
+    const auto actions = actionCollection->actions();
+    for (QAction *action : actions) {
         // skip our active ones
         if (active_list.contains(action->objectName())) {
             continue;
@@ -1312,25 +1319,21 @@ void KEditToolBarWidgetPrivate::slotToolBarSelected(int index)
     // To do that, we do the same iteration as the one which filled in the combobox.
 
     int toolbarNumber = 0;
-    XmlDataList::iterator xit = m_xmlFiles.begin();
-    for (; xit != m_xmlFiles.end(); ++xit) {
-
+    for (auto &xmlFile : m_xmlFiles) {
         // skip the merged one in favor of the local one,
         // so that we can change icons
-        if ((*xit).type() == XmlData::Merged) {
+        if (xmlFile.type() == XmlData::Merged) {
             continue;
         }
 
         // each xml file may have any number of toolbars
-        ToolBarList::Iterator it = (*xit).barList().begin();
-        for (; it != (*xit).barList().end(); ++it) {
-
+        for (const auto &bar : xmlFile.barList()) {
             // is this our toolbar?
             if (toolbarNumber == index) {
 
                 // save our current settings
-                m_currentXmlData = & (*xit);
-                m_currentToolBarElem = *it;
+                m_currentXmlData = &xmlFile;
+                m_currentToolBarElem = bar;
 
                 //qCDebug(DEBUG_KXMLGUI) << "found toolbar" << m_currentXmlData->toolBarText(*it) << "m_currentXmlData set to";
                 m_currentXmlData->dump();
@@ -1341,8 +1344,8 @@ void KEditToolBarWidgetPrivate::slotToolBarSelected(int index)
                 // load in our values
                 loadActions(m_currentToolBarElem);
 
-                if ((*xit).type() == XmlData::Part || (*xit).type() == XmlData::Shell) {
-                    m_widget->setDOMDocument((*xit).domDocument());
+                if (xmlFile.type() == XmlData::Part || xmlFile.type() == XmlData::Shell) {
+                    m_widget->setDOMDocument(xmlFile.domDocument());
                 }
                 return;
             }
@@ -1566,39 +1569,37 @@ void KEditToolBarWidgetPrivate::slotDownButton()
 
 void KEditToolBarWidgetPrivate::updateLocal(QDomElement &elem)
 {
-    XmlDataList::Iterator xit = m_xmlFiles.begin();
-    for (; xit != m_xmlFiles.end(); ++xit) {
-        if ((*xit).type() == XmlData::Merged) {
+    for (auto &xmlFile : m_xmlFiles) {
+        if (xmlFile.type() == XmlData::Merged) {
             continue;
         }
 
-        if ((*xit).type() == XmlData::Shell ||
-                (*xit).type() == XmlData::Part) {
-            if (m_currentXmlData->xmlFile() == (*xit).xmlFile()) {
-                (*xit).m_isModified = true;
+        if (xmlFile.type() == XmlData::Shell ||
+                xmlFile.type() == XmlData::Part) {
+            if (m_currentXmlData->xmlFile() == xmlFile.xmlFile()) {
+                xmlFile.m_isModified = true;
                 return;
             }
 
             continue;
         }
 
-        (*xit).m_isModified = true;
+        xmlFile.m_isModified = true;
         const QLatin1String attrName("name");
-        ToolBarList::Iterator it = (*xit).barList().begin();
-        for (; it != (*xit).barList().end(); ++it) {
-            QString name((*it).attribute(attrName));
-            QString tag((*it).tagName());
+        for (const auto &bar : qAsConst(xmlFile.barList())) {
+            const QString name(bar.attribute(attrName));
+            const QString tag(bar.tagName());
             if ((tag != elem.tagName()) || (name != elem.attribute(attrName))) {
                 continue;
             }
 
-            QDomElement toolbar = (*xit).domDocument().documentElement().toElement();
-            toolbar.replaceChild(elem, (*it));
+            QDomElement toolbar = xmlFile.domDocument().documentElement().toElement();
+            toolbar.replaceChild(elem, bar);
             return;
         }
 
         // just append it
-        QDomElement toolbar = (*xit).domDocument().documentElement().toElement();
+        QDomElement toolbar = xmlFile.domDocument().documentElement().toElement();
         Q_ASSERT(!toolbar.isNull());
         toolbar.appendChild(elem);
     }
